# ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
# Date: 16.11.2016                                                            #
# Author: Ole-Johan Skrede                                                    #
#                                                                             #
# Solution proposal as part of the exercise program in                        #
# INF4300 - Digital image analysis at the University of Oslo                  #
#                                                                             #
# ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
"""
Solution proposal for exercise 11, task 3.
"""

# pylint: disable=expression-not-assigned
# pylint: disable=bad-indentation
# pylint: disable=redefined-outer-name
# pylint: disable=import-error

import os

import numpy as np
import matplotlib.pyplot as plt
import seaborn

def plot_lattice(image, fig_num, write_file=None):
  """Plot image with lattice in pixel borders"""
  fig = plt.figure(fig_num)
  ax = fig.add_subplot(111)
  ax.imshow(image, cmap='gray', interpolation='none')
  ax.set_xticks(np.arange(0, image.shape[1]))
  ax.set_xticks(np.arange(0.5, image.shape[1] + 0.5), minor=True)
  ax.get_xaxis().set_ticks([]) # Hide tick labels
  ax.set_yticks(np.arange(0, image.shape[0]))
  ax.set_yticks(np.arange(0.5, image.shape[0] + 0.5), minor=True)
  ax.get_yaxis().set_ticks([]) # Hide tick labels
  ax.grid(b=True, which='minor', linestyle='-', color='lightgray')
  if write_file:
    fig.savefig(write_file, bbox_inches='tight', pad_inches=0)
  plt.tight_layout()

  fig_num += 1
  return fig_num

def main():
  """Segmentation of cells"""

  print('='*80)
  print('Solution to weekly exercises in INF4300')
  print('Exercise 11')
  print('Task 3 and 4')
  print('-'*80)

  # Configurations
  result_dir = 'results/images'

  # Dummy image for task 3
  img = np.array([[0, 0, 0, 0, 0, 0, 0, 0],
                  [0, 0, 0, 0, 0, 0, 0, 0],
                  [0, 0, 1, 1, 1, 1, 0, 0],
                  [0, 0, 1, 1, 1, 1, 0, 0],
                  [0, 0, 1, 0, 0, 1, 0, 0],
                  [0, 0, 1, 0, 0, 1, 0, 0],
                  [0, 0, 0, 0, 0, 0, 0, 0],
                  [0, 0, 0, 0, 0, 0, 0, 0]], dtype=np.uint8)

  #fig_num = plot_lattice(img, 0,
  #                       write_file=os.path.join(result_dir, 't03_image.png'))

  # Dummy image for task 4
  data = np.array([0, 0, 2, 7, 4, 4, 5, 6, 5, 2, 2, 4, 2, 1, 0])

  fig = plt.figure(1)
  plt.bar(np.arange(1, len(data)+1), data, align='center', width=1)
  fig.savefig(os.path.join(result_dir, 't04_data.png'), bbox_inches='tight', pad_inches=0)

  plt.show()

if __name__ == "__main__":
  main()
